# python-openevse-http
Python Library for OpenEVSE HTTP API

A python library for communicating with the ESP8266- and ESP32-based wifi module from OpenEVSE. This library uses the HTTP API commands to query the OpenEVSE charger.

TODO:
- [ ] Finish tests
- [ ] Finish HTTP API functions
- [X] Setup webosocket listener for value updates
- [X] Convert to aiohttp from requests
- [X] Expose values as properties
